@@ -5,6 +5,12 @@ if (!isset($_REQUEST['id'])) {
 }
 $id = (string)$_REQUEST['id'];
 
+// sanitize the input
+$sid = SimpleSAML_Utilities::parseStateID($id);
+if (!is_null($sid['url'])) {
+	SimpleSAML_Utilities::checkURLAllowed($sid['url']);
+}
+
 $state = SimpleSAML_Auth_State::loadState($id, 'core:Logout:afterbridge');
 $idp = SimpleSAML_IdP::getByState($state);
 
