@@ -1,10 +1,20 @@
 <?php
 
+/**
+ * WARNING:
+ *
+ * THIS FILE IS DEPRECATED AND WILL BE REMOVED IN FUTURE VERSIONS
+ *
+ * @deprecated
+ */
+
 require_once('../_include.php');
 
-$session = SimpleSAML_Session::getInstance();
+$session = SimpleSAML_Session::getSessionFromRequest();
 $metadata = SimpleSAML_Metadata_MetaDataStorageHandler::getMetadataHandler();
 
+SimpleSAML_Logger::warning('The file example-simple/attributequery.php is deprecated and will be removed in future versions.');
+
 $spEntityId = $metadata->getMetaDataCurrentEntityID('saml20-sp-hosted');
 
 function sendQuery($dataId, $url, $nameId) {
@@ -61,7 +71,7 @@ function handleResponse() {
 	$data['attributes'] = $assertion->getAttributes();
 	$GLOBALS['session']->setData('attributequeryexample:data', $dataId, $data, 3600);
 
-	SimpleSAML_Utilities::redirect(SimpleSAML_Utilities::selfURLNoQuery(),
+	SimpleSAML_Utilities::redirectTrustedURL(SimpleSAML_Utilities::selfURLNoQuery(),
 		array('dataId' => $dataId));
 }
 
